<?php

namespace app\api\controller\Customer;

use app\BaseController;
use app\common\model\Customer\CustomerMessage as ModelCustomerMessage;
use app\Request;
use think\Validate;
use think\exception\ValidateException;
use think\facade\Filesystem;
use app\common\arw\adjfut\src\Excel;
use app\common\arw\adjfut\src\UploadFile;
use app\common\model\Token as ModelToken;
use app\common\exception\Tool;
use think\facade\Db;
use think\facade\Env;
use app\BaseModel;


class CustomerMessage extends BaseController
{
    /**
     * 获取客户消息列表接口
     * 
     * @param Request $request
     * @return array
     * @date 2023-08-01
     * @author xjh
     * @since 1.0.0
     */
    public function getCustomerMessageList(Request $request, $isExport = false): array
    {
        $customer = ModelToken::getCurrentCustomer();

        $query = ModelCustomerMessage::where('customer_message.customer_guid', $customer->customer_guid)
            ->field([
                'customer_message.customer_message_guid',
                'customer_message.customer_message_title',
                'customer_message.customer_message_content',
                'customer_message.customer_message_postscript',
                'customer_message.customer_message_reading_status',
                'customer_message.customer_message_create_time',
                'customer.customer_name',
                'customer.customer_email',
            ])
            ->leftjoin('customer', 'customer.customer_guid = customer_message.customer_guid ')
            ->order('customer_message_update_time', 'desc');

        return msg("获取客户消息列表成功!", $query);
    }

    /**
     * 客户消息设置已读接口
     * 
     * @param Request $request
     * @return array
     * @date 2023-08-01
     * @author xjh
     * @since 1.0.0
     */
    public function haveReadCustomerMessage(Request $request): array
    {
        $customer = ModelToken::getCurrentCustomer();
        $params = $request->param();
        $this->validate($params, [
            'customer_message_guid|客户消息guid' => 'require',
        ]);
        BaseModel::setUserGuid(false);
        ModelCustomerMessage::update(['customer_message_reading_status' => ModelCustomerMessage::HAVE_READ], [
            'customer_message_guid' => $params['customer_message_guid'],
            'customer_guid' => $customer->customer_guid,
            'customer_message_reading_status' => ModelCustomerMessage::UNREAD,
        ]);
        return msg("客户消息设置已读成功!");
    }

    /**
     * 客户消息一键设置全部已读接口
     * 
     * @param Request $request
     * @return array
     * @date 2023-08-01
     * @author xjh
     * @since 1.0.0
     */
    public function haveReadAllCustomerMessage(Request $request): array
    {
        $customer = ModelToken::getCurrentCustomer();
        BaseModel::setUserGuid(false);
        ModelCustomerMessage::where([
            'customer_guid' => $customer->customer_guid,
            'customer_message_reading_status' => ModelCustomerMessage::UNREAD,
        ])->select()->update(['customer_message_reading_status' => ModelCustomerMessage::HAVE_READ]);
        return msg("客户消息设一键设置全部已读成功!");
    }
}