<?php

namespace app\api\logic\Code;

use app\common\model\Code\CodeModuleCategory as ModelCodeModuleCategory;
use app\api\logic\Code\CodeModuleCategory as LogicCodeModuleCategory;
use app\common\model\Code\CodeModule as ModelCodeModule;
use app\common\model\Token as ModelToken;
use app\common\exception\Tool;


class CodeModule
{
    /**
     * 构建客户代码块初始审核状态
     * 
     * @param string $code_module_category_guid 所属类目guid
     * @return int 审核状态
     * @date 2023-07-19
     * @author xjh
     * @since 1.0.0
     */
    public static function buildCodeModuleAudit(string $code_module_category_guid): int
    {
        $category = ModelCodeModuleCategory::find($code_module_category_guid);
        if (!$category) {
            throwErrorMsg("代码块所属类目不存在!");
        }
        return LogicCodeModuleCategory::buildCodeModuleCategoryAudit($category->code_module_category_library_type);
    }

    /**
     * 代码块新增验证
     * 
     * @param array $params 新增代码块的参数
     * @return void
     * @date 2023-07-12
     * @author xjh
     * @since 1.0.0
     */
    public static function validateAddCodeModule(array $params): void
    {
        LogicCodeModuleCategory::validateOpCodeModuleCategoryParent($params['code_module_category_guid']);
    }

    /**
     * 代码块编辑验证
     * 
     * @param array $params 编辑代码块的参数
     * @return void
     * @date 2023-07-14
     * @author xjh
     * @since 1.0.0
     */
    public static function validateEditCodeModule(array $params): void
    {
        LogicCodeModuleCategory::validateOpCodeModuleCategoryParent($params['code_module_category_guid']);
        self::validateOpCodeModule($params['code_module_guid']);
    }

    /**
     * 代码块删除验证
     * 
     * @param string $code_module_guid 代码块guid
     * @return void
     * @date 2023-07-14
     * @author xjh
     * @since 1.0.0
     */
    public static function validateDeleteCodeModule(string $code_module_guid): void
    {
        self::validateOpCodeModule($code_module_guid);
    }

    /**
     * 代码块操作验证
     * 
     * @param string $code_module_guid 代码块guid
     * @return void
     * @date 2023-07-20
     * @author xjh
     * @since 1.0.0
     */
    public static function validateOpCodeModule(string $code_module_guid): void
    {
        $module = ModelCodeModule::find($code_module_guid);
        if (!$module) {
            throwErrorMsg("所操作的代码块不存在!");
        }
        if ($module->customer_guid != ModelToken::getCurrentCustomer()->customer_guid) {
            throwErrorMsg("所操作的代码块不属于当前客户!");
        }
    }
}